@@ -1,6 +1,6 @@
 /*
  * Copyright 2000,2001 F.W. Dillema, University of Tromso, Norway
- * $Id: www6to4.c,v 1.37 2001/12/17 15:10:58 dillema Exp $
+ * $Id: www6to4.c,v 1.38 2003/11/26 09:49:06 dillema Exp $
  *
  * Distributed under the GNU General Public License; see the README file.
  * http://www.vermicelli.pasta.cs.uit.no/ipv6/software/
@@ -15,7 +15,7 @@
 #define SYSLOG_NAMES
 #include "www6to4.h"
 
-#define VERSION "www6to4 v1.5"
+#define VERSION "www6to4 v1.6"
 #define BANNER  "<strong>"VERSION"</strong>"
 
 char CFAIL[] = "HTTP/1.0 503 Connect failed\r\n"
@@ -63,11 +63,13 @@ char *default_configfile = "/etc/www6to4.conf";
 char *configfile = NULL;
 char *forwardfile = NULL;
 int debug = 0;
+int forwardv4only = 0;
 int quiet = 1;
 int tfactor = 1;
 int potential_add;
 int logfacility = LOG_DAEMON;
 struct gateway gw_default = {NULL, NULL};
+struct gateway gw_none = {NULL, NULL};
 
 struct file_list *current_forwardfile;
 int (*loaders[NLOADERS]) ();
@@ -430,6 +432,8 @@ int main (int argc, char *argv[]) {
     for (i = 1; i < argc; i++) {
         if (!strcmp (argv[i], "-d") )
             debug = 1;
+        else if (!strcmp (argv[i], "-forwardv4only"))
+                forwardv4only = 1;
         else if (!strcmp (argv[i], "-c"))
             configfile = strdup(argv[++i]);
         else if (!strcmp (argv[i], "-l")) {
@@ -449,6 +453,7 @@ int main (int argc, char *argv[]) {
                 quiet = -1;
         else if (!strcmp (argv[i], "-h")) {
                 fprintf (stdout, "www6to4 -q -v -h  -d -c <configfile> -l <syslogfacility>\n");
+                fprintf (stdout, "-forwardv4only: never forward requests for IPv6 hosts\n");
                 fprintf (stdout, "-q: quiet (less logging)\n");
                 fprintf (stdout, "-v: verbose (more logging)\n");
                 fprintf (stdout, "-d: debug mode (do not fork)\n");
